pub struct Track {Show 14 fields
pub path: PathBuf,
pub cover_path: Option<PathBuf>,
pub duration: Duration,
pub artist: Option<String>,
pub title: Option<String>,
pub album: Option<String>,
pub genre: Option<String>,
pub lyrics: Option<Lyrics>,
pub comment: Option<String>,
pub track: Option<u32>,
pub track_total: Option<u32>,
pub disc: Option<u32>,
pub disc_total: Option<u32>,
pub date: Option<Timestamp>,
}Fields
path: PathBufcover_path: Option<PathBuf>duration: Durationartist: Option<String>title: Option<String>album: Option<String>genre: Option<String>lyrics: Option<Lyrics>comment: Option<String>track: Option<u32>track_total: Option<u32>disc: Option<u32>disc_total: Option<u32>date: Option<Timestamp>Implementations
Sourceimpl Track
impl Track
Sourcepub fn get_cover(&mut self, tag: &Tag) -> Result<(), CoverError>
pub fn get_cover(&mut self, tag: &Tag) -> Result<(), CoverError>
Set the cover art from cache or extract it from the source file.
Sourcepub fn extract_cover(&mut self, tag: &Tag) -> Result<(), CoverError>
pub fn extract_cover(&mut self, tag: &Tag) -> Result<(), CoverError>
Extract the cover art from the source file discarding the cache contents.
pub fn hash_self(&self) -> u64
pub fn hash_track(track: &Track) -> u64
pub fn hash_tracks(tracks: &Vec<Track>) -> Vec<u64>
pub fn track_id(&self, position: usize) -> TrackId
pub fn get_meta(&self, position: usize) -> Metadata
pub fn open_file(&self) -> Result<File>
pub fn open_source(&self) -> Result<Decoder<BufReader<File>>, String>